========================
RIMS Evaluation Software
========================


.. image:: https://github.com/RIMS-Code/RIMSEval/workflows/rimseval-tests/badge.svg?branch=main
    :target: https://github.com/RIMS-Code/RIMSEval
    :alt: Tests rimseval
.. image:: https://img.shields.io/pypi/v/rimseval?color=informational
    :target: https://pypi.org/project/rimseval/
    :alt: PyPi rimseval
.. image:: https://readthedocs.org/projects/rimseval/badge/?version=latest
    :target: https://rimseval.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
.. image:: https://coveralls.io/repos/github/RIMS-Code/RIMSEval/badge.svg?branch=main
    :target: https://coveralls.io/github/RIMS-Code/RIMSEval?branch=main
    :alt: Coverage Status
.. image:: https://img.shields.io/badge/License-MIT-blue.svg
    :target: https://github.com/RIMS-Code/RIMSEval/blob/main/LICENSE
    :alt: License: MIT
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Code style: black

--------
Welcome!
--------

The goal of this project is to give the user
an API as well as a GUI interface to evaluate RIMS spectra.
All code is available on
`GitHub <https://github.com/RIMS-Code/RIMSEval>`_.

Please check the sections below for help on installation,
usage, etc.

--------
Contents
--------

.. toctree::
    :maxdepth: 2

    license

.. toctree::
    :maxdepth: 2
    :caption: Package Users

    pkg/install
    pkg/usage
    pkg/guis
    pkg/filters
    pkg/variables
    pkg/special

.. toctree::
    :maxdepth: 2
    :caption: GUI Users

    gui/install
    gui/gui

.. toctree::
    :maxdepth: 2
    :caption: Macros

    macro_dev/macros

.. toctree::
    :maxdepth: 2
    :caption: Scientific Background

    bg/deltas
    bg/integrals

.. toctree::
    :maxdepth: 2
    :caption: Macro Development

.. toctree::
    :maxdepth: 2
    :caption: Developers

    dev/dev
    dev/api/index
